queue

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 29, 2023 License: MIT Imports: 5 Imported by: 0

README

rpc-queue

rpc-queue aims to be a quick and dirty way of sending gob-encoded data to a sidecar worker.

It achieves this by providing a very minimal API, consisting of only two functions: Send and Listen.

There are only two rules you must follow:

  • Data sent through Send must be of the same type a caller defines their Listen on.
  • A sender must not listen and a listener must not send.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Listen

func Listen[T any](ctx context.Context) <-chan *T

func Send

func Send(t any) error

Types

This section is empty.

Directories

Path Synopsis
examples
client command
server command
internal

Jump to